@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: slider.sh,v 1.4 2005/12/27 15:53:06 tom Exp $
+# $Id: slider.sh,v 1.5 2022/10/18 23:54:17 tom Exp $
 
 #
 # Description:
@@ -27,29 +27,31 @@ buttons=" OK
 #
 # Create the slider box.
 #
-${CDK_SLIDER} -f 20 -l 0 -h 100 -i 5 -L "${label}" -T "${title}" -F "</R>*" -B "${buttons}" -O ${output}
+${CDK_SLIDER} -f 20 -l 0 -h 100 -i 5 -L "${label}" -T "${title}" -F "</R>*" -B "${buttons}" -O "${output}"
 selected=$?
 test $selected = 255 && exit 1
 
-answer=`cat ${output}`
+answer=`cat "${output}"`
 
 #
 # Create the message for the label widget.
 #
-echo "<C>Here is the value you selected" > ${tmp}
-echo " " >> ${tmp}
-echo "<C></R>${answer}" >> ${tmp}
-echo " " >> ${tmp}
-echo "<C>You chose button #${selected}" >> ${tmp}
-echo " " >> ${tmp}
-echo "<C>Hit </R>space<!R> to continue." >> ${tmp}
+cat >"${tmp}" <<EOF
+<C>Here is the value you selected
+
+<C></R>${answer}
+
+<C>You chose button #${selected}
+
+<C>Hit </R>space<!R> to continue.
+EOF
 
 #
 # Create the label widget to display the information.
 #
-${CDK_LABEL} -f ${tmp} -p " "
+${CDK_LABEL} -f "${tmp}" -p " "
 
 #
 # Clean up.
 #
-rm -f ${tmp} ${output}
+rm -f "${tmp}" "${output}"
